@@ -657,7 +657,7 @@ class ThreeDAssetMappingAPI(APIClient):
             [ThreeDAssetMapping(a.node_id, a.asset_id).dump(camel_case=True) for a in asset_mapping], self._DELETE_LIMIT
         )
         tasks = [{"url_path": path + "/delete", "json": {"items": chunk}} for chunk in chunks]
-        summary = utils._concurrency.execute_tasks_concurrently(self._post, tasks, self._config.max_workers)
+        summary = utils._concurrency.execute_tasks(self._post, tasks, self._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks(
             task_unwrap_fn=lambda task: task["json"]["items"],
             task_list_element_unwrap_fn=lambda el: ThreeDAssetMapping._load(el),
